#!/bin/sh

SYFI_VERSION=0.6.2

rm -f syfi-$SYFI_VERSION.tar.gz 

PPWD=$PWD

cd ..
rm dorsal_build 
scons -c  
cd demo 
python cleanall.py 
cd ..

cd ..
cp -r fenics-syfi syfi-$SYFI_VERSION
files=`find syfi-$SYFI_VERSION -type f| grep -v bzr` 
#echo $files 
tar -cf syfi-$SYFI_VERSION.tar $files  
gzip syfi-$SYFI_VERSION.tar
ls -s syfi-$SYFI_VERSION.tar.gz
cp syfi-$SYFI_VERSION.tar.gz $PPWD

